@@ -1,29 +1,28 @@
 from fractions import Fraction
-from typing import (Callable,
-                    Sequence,
+from typing import (Sequence,
                     Tuple,
                     Type)
 
 from ground.core.hints import (Contour,
-                               Coordinate,
-                               Point)
+                               Point,
+                               Polygon,
+                               Scalar)
 from .region import centroid_components as region_centroid_components
 
 
-def centroid(border: Contour,
-             holes: Sequence[Contour],
+def centroid(polygon: Polygon,
              point_cls: Type[Point],
-             inverse: Callable[[int], Fraction] = Fraction(1).__truediv__
-             ) -> Point:
-    x_numerator, y_numerator, double_area = centroid_components(border, holes)
-    inverted_denominator = inverse(3 * double_area)
+             third: Fraction = Fraction(1, 3)) -> Point:
+    x_numerator, y_numerator, double_area = centroid_components(polygon.border,
+                                                                polygon.holes)
+    inverted_denominator = third / double_area
     return point_cls(x_numerator * inverted_denominator,
                      y_numerator * inverted_denominator)
 
 
 def centroid_components(border: Contour,
                         holes: Sequence[Contour]
-                        ) -> Tuple[Coordinate, Coordinate, Coordinate]:
+                        ) -> Tuple[Scalar, Scalar, Scalar]:
     x_numerator, y_numerator, double_area = region_centroid_components(
             border.vertices)
     for hole in holes:
