@@ -1,15 +1,16 @@
 from typing import (Callable,
-                    Sequence,
                     Type)
 
-from ground.core.hints import (Coordinate,
-                               Point)
+from ground.core.hints import (Contour,
+                               Point,
+                               Scalar)
 from ground.core.shewchuk import to_squared_points_distance
 
 
-def centroid(vertices: Sequence[Point],
+def centroid(contour: Contour,
              point_cls: Type[Point],
-             sqrt: Callable[[Coordinate], Coordinate]) -> Point:
+             sqrt: Callable[[Scalar], Scalar]) -> Point:
+    vertices = contour.vertices
     accumulated_x = accumulated_y = accumulated_length = 0
     vertex = vertices[-1]
     start_x, start_y = vertex.x, vertex.y
